<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <title>webpty v{{app_version}}</title>
  <link rel="preconnect" href="https://fonts.gstatic.com">
  <link href="https://fonts.googleapis.com/css2?family=Source+Code+Pro&display=swap" rel="stylesheet">
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/xterm@5.0.0/css/xterm.css" />
  <link rel="stylesheet" href=".{{ static_url("webpty.min.css") }}" />
</head>
<body>
    <div id="webpty"></div>
    <script>
        const APP_SECURED = {% if is_secured %} true {% else %} false {% end %};
        const KEEP_ALIVE = {{keepalive}};
    </script>
    <script src="https://cdn.jsdelivr.net/npm/xterm@5.0.0/lib/xterm.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/xterm-addon-fit@0.6.0/lib/xterm-addon-fit.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/xterm-addon-web-links@0.7.0/lib/xterm-addon-web-links.min.js"></script>
    <script src=".{{ static_url("webpty.min.js") }}"></script>
</body>
</html>
