* {
  margin: 0;
  font-family: "Source Code Pro", "Source Code Variable" monospace !important;
}

body {
  height: 100%;
  width: 100%;
  background-color: black;
}

#webpty {
  overflow: hidden;
  width: 100vw;
  height: 100vh;
}
